================
For contributing
================

Thank you for interested to ``sphinx-revealjs``.

If you are
==========

using
-----

Please share and publish about using (I am glad for it!).

aving questions
---------------

Please post `Discussions <https://github.com/attakei/sphinx-revealjs/discussions>`_.

find typo in sources, doc and demo
----------------------------------

Please post `PR <https://github.com/attakei/sphinx-revealjs/pulls>`_ directly (not need create issue).

find bugs in sources
--------------------

Please create `issue <https://github.com/attakei/sphinx-revealjs/issues>`_ first.

want features for this
----------------------

1. Please think first: "Does features that you want have deep-dependency for sphinx-revealjs?".
1. If features need based-on sphinx-revealjs, please create issue.
1. I think about "does this need for sphinx-revealjs", but I not always implement/accept PR for it.

See more
========

Writing `"contributing" <https://sphinx-revealjs.readthedocs.io/en/stable/contributing/>`_ page in documentation.
